@@ -9,6 +9,7 @@ import textwrap
 import types
 
 import attr
+import importlib_metadata
 import py
 import six
 
@@ -111,8 +112,6 @@ class TestGeneralUsage(object):
 
     @pytest.mark.parametrize("load_cov_early", [True, False])
     def test_early_load_setuptools_name(self, testdir, monkeypatch, load_cov_early):
-        pkg_resources = pytest.importorskip("pkg_resources")
-
         testdir.makepyfile(mytestplugin1_module="")
         testdir.makepyfile(mytestplugin2_module="")
         testdir.makepyfile(mycov_module="")
@@ -124,38 +123,28 @@ class TestGeneralUsage(object):
         class DummyEntryPoint(object):
             name = attr.ib()
             module = attr.ib()
-            version = "1.0"
-
-            @property
-            def project_name(self):
-                return self.name
+            group = "pytest11"
 
             def load(self):
                 __import__(self.module)
                 loaded.append(self.name)
                 return sys.modules[self.module]
 
-            @property
-            def dist(self):
-                return self
-
-            def _get_metadata(self, *args):
-                return []
-
         entry_points = [
             DummyEntryPoint("myplugin1", "mytestplugin1_module"),
             DummyEntryPoint("myplugin2", "mytestplugin2_module"),
             DummyEntryPoint("mycov", "mycov_module"),
         ]
 
-        def my_iter(group, name=None):
-            assert group == "pytest11"
-            for ep in entry_points:
-                if name is not None and ep.name != name:
-                    continue
-                yield ep
+        @attr.s
+        class DummyDist(object):
+            entry_points = attr.ib()
+            files = ()
 
-        monkeypatch.setattr(pkg_resources, "iter_entry_points", my_iter)
+        def my_dists():
+            return (DummyDist(entry_points),)
+
+        monkeypatch.setattr(importlib_metadata, "distributions", my_dists)
         params = ("-p", "mycov") if load_cov_early else ()
         testdir.runpytest_inprocess(*params)
         if load_cov_early:
@@ -428,9 +417,20 @@ class TestGeneralUsage(object):
             assert result.ret == 4  # usage error only if item not found
 
     def test_report_all_failed_collections_initargs(self, testdir):
+        testdir.makeconftest(
+            """
+            from _pytest.main import EXIT_USAGEERROR
+
+            def pytest_sessionfinish(exitstatus):
+                assert exitstatus == EXIT_USAGEERROR
+                print("pytest_sessionfinish_called")
+            """
+        )
         testdir.makepyfile(test_a="def", test_b="def")
         result = testdir.runpytest("test_a.py::a", "test_b.py::b")
         result.stderr.fnmatch_lines(["*ERROR*test_a.py::a*", "*ERROR*test_b.py::b*"])
+        result.stdout.fnmatch_lines(["pytest_sessionfinish_called"])
+        assert result.ret == EXIT_USAGEERROR
 
     @pytest.mark.usefixtures("recwarn")
     def test_namespace_import_doesnt_confuse_import_hook(self, testdir):
@@ -865,7 +865,9 @@ class TestInvocationVariants(object):
                 _fail, _sep, testid = line.partition(" ")
                 break
         result = testdir.runpytest(testid, "-rf")
-        result.stdout.fnmatch_lines([line, "*1 failed*"])
+        result.stdout.fnmatch_lines(
+            ["FAILED test_doctest_id.txt::test_doctest_id.txt", "*1 failed*"]
+        )
 
     def test_core_backward_compatibility(self):
         """Test backward compatibility for get_plugin_manager function. See #787."""
