@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
@@ -147,7 +148,7 @@ def test_pytest_plugins_in_non_top_level_conftest_unsupported_pyargs(
     if use_pyargs:
         assert msg not in res.stdout.str()
     else:
-        res.stdout.fnmatch_lines("*{msg}*".format(msg=msg))
+        res.stdout.fnmatch_lines(["*{msg}*".format(msg=msg)])
 
 
 def test_pytest_plugins_in_non_top_level_conftest_unsupported_no_top_level_conftest(
