@@ -11,6 +11,7 @@ import six
 
 import _pytest.assertion as plugin
 import pytest
+from _pytest import outcomes
 from _pytest.assertion import truncate
 from _pytest.assertion import util
 
@@ -136,12 +137,12 @@ class TestImportHookInstallation(object):
     def test_pytest_plugins_rewrite_module_names_correctly(self, testdir):
         """Test that we match files correctly when they are marked for rewriting (#2939)."""
         contents = {
-            "conftest.py": """
+            "conftest.py": """\
                 pytest_plugins = "ham"
             """,
             "ham.py": "",
             "hamster.py": "",
-            "test_foo.py": """
+            "test_foo.py": """\
                 def test_foo(pytestconfig):
                     assert pytestconfig.pluginmanager.rewrite_hook.find_module('ham') is not None
                     assert pytestconfig.pluginmanager.rewrite_hook.find_module('hamster') is None
@@ -152,14 +153,13 @@ class TestImportHookInstallation(object):
         assert result.ret == 0
 
     @pytest.mark.parametrize("mode", ["plain", "rewrite"])
-    @pytest.mark.parametrize("plugin_state", ["development", "installed"])
-    def test_installed_plugin_rewrite(self, testdir, mode, plugin_state, monkeypatch):
+    def test_installed_plugin_rewrite(self, testdir, mode, monkeypatch):
         monkeypatch.delenv("PYTEST_DISABLE_PLUGIN_AUTOLOAD", raising=False)
         # Make sure the hook is installed early enough so that plugins
         # installed via setuptools are rewritten.
         testdir.tmpdir.join("hampkg").ensure(dir=1)
         contents = {
-            "hampkg/__init__.py": """
+            "hampkg/__init__.py": """\
                 import pytest
 
                 @pytest.fixture
@@ -168,7 +168,7 @@ class TestImportHookInstallation(object):
                         assert values.pop(0) == value
                     return check
             """,
-            "spamplugin.py": """
+            "spamplugin.py": """\
             import pytest
             from hampkg import check_first2
 
@@ -178,46 +178,31 @@ class TestImportHookInstallation(object):
                     assert values.pop(0) == value
                 return check
             """,
-            "mainwrapper.py": """
-            import pytest, pkg_resources
-
-            plugin_state = "{plugin_state}"
-
-            class DummyDistInfo(object):
-                project_name = 'spam'
-                version = '1.0'
-
-                def _get_metadata(self, name):
-                    # 'RECORD' meta-data only available in installed plugins
-                    if name == 'RECORD' and plugin_state == "installed":
-                        return ['spamplugin.py,sha256=abc,123',
-                                'hampkg/__init__.py,sha256=abc,123']
-                    # 'SOURCES.txt' meta-data only available for plugins in development mode
-                    elif name == 'SOURCES.txt' and plugin_state == "development":
-                        return ['spamplugin.py',
-                                'hampkg/__init__.py']
-                    return []
+            "mainwrapper.py": """\
+            import pytest, importlib_metadata
 
             class DummyEntryPoint(object):
                 name = 'spam'
                 module_name = 'spam.py'
-                attrs = ()
-                extras = None
-                dist = DummyDistInfo()
+                group = 'pytest11'
 
-                def load(self, require=True, *args, **kwargs):
+                def load(self):
                     import spamplugin
                     return spamplugin
 
-            def iter_entry_points(group, name=None):
-                yield DummyEntryPoint()
+            class DummyDistInfo(object):
+                version = '1.0'
+                files = ('spamplugin.py', 'hampkg/__init__.py')
+                entry_points = (DummyEntryPoint(),)
+                metadata = {'name': 'foo'}
 
-            pkg_resources.iter_entry_points = iter_entry_points
+            def distributions():
+                return (DummyDistInfo(),)
+
+            importlib_metadata.distributions = distributions
             pytest.main()
-            """.format(
-                plugin_state=plugin_state
-            ),
-            "test_foo.py": """
+            """,
+            "test_foo.py": """\
             def test(check_first):
                 check_first([10, 30], 30)
 
@@ -445,6 +430,50 @@ class TestAssert_reprcompare(object):
         assert "Omitting" not in lines[1]
         assert lines[2] == "{'b': 1}"
 
+    def test_dict_different_items(self):
+        lines = callequal({"a": 0}, {"b": 1, "c": 2}, verbose=2)
+        assert lines == [
+            "{'a': 0} == {'b': 1, 'c': 2}",
+            "Left contains 1 more item:",
+            "{'a': 0}",
+            "Right contains 2 more items:",
+            "{'b': 1, 'c': 2}",
+            "Full diff:",
+            "- {'a': 0}",
+            "+ {'b': 1, 'c': 2}",
+        ]
+        lines = callequal({"b": 1, "c": 2}, {"a": 0}, verbose=2)
+        assert lines == [
+            "{'b': 1, 'c': 2} == {'a': 0}",
+            "Left contains 2 more items:",
+            "{'b': 1, 'c': 2}",
+            "Right contains 1 more item:",
+            "{'a': 0}",
+            "Full diff:",
+            "- {'b': 1, 'c': 2}",
+            "+ {'a': 0}",
+        ]
+
+    def test_sequence_different_items(self):
+        lines = callequal((1, 2), (3, 4, 5), verbose=2)
+        assert lines == [
+            "(1, 2) == (3, 4, 5)",
+            "At index 0 diff: 1 != 3",
+            "Right contains one more item: 5",
+            "Full diff:",
+            "- (1, 2)",
+            "+ (3, 4, 5)",
+        ]
+        lines = callequal((1, 2, 3), (4,), verbose=2)
+        assert lines == [
+            "(1, 2, 3) == (4,)",
+            "At index 0 diff: 1 != 4",
+            "Left contains 2 more items, first extra item: 2",
+            "Full diff:",
+            "- (1, 2, 3)",
+            "+ (4,)",
+        ]
+
     def test_set(self):
         expl = callequal({0, 1}, {0, 2})
         assert len(expl) > 1
@@ -560,7 +589,10 @@ class TestAssert_reprcompare(object):
                 return "\xff"
 
         expl = callequal(A(), "1")
-        assert expl
+        if PY3:
+            assert expl == ["ÿ == '1'", "+ 1"]
+        else:
+            assert expl == [u"\ufffd == '1'", u"+ 1"]
 
     def test_format_nonascii_explanation(self):
         assert util.format_explanation("λ")
@@ -1305,3 +1337,13 @@ def test_issue_1944(testdir):
         "AttributeError: 'Module' object has no attribute '_obj'"
         not in result.stdout.str()
     )
+
+
+def test_exit_from_assertrepr_compare(monkeypatch):
+    def raise_exit(obj):
+        outcomes.exit("Quitting debugger")
+
+    monkeypatch.setattr(util, "istext", raise_exit)
+
+    with pytest.raises(outcomes.Exit, match="Quitting debugger"):
+        callequal(1, 1)
