@@ -1,4 +1,4 @@
-# -*- coding: utf8 -*-
+# -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
 import sys
@@ -95,10 +95,12 @@ def test_as_errors(testdir, pyfile_with_warnings, method):
         testdir.makeini(
             """
             [pytest]
-            filterwarnings= error
+            filterwarnings=error
             """
         )
-    result = testdir.runpytest(*args)
+    # Use a subprocess, since changing logging level affects other threads
+    # (xdist).
+    result = testdir.runpytest_subprocess(*args)
     result.stdout.fnmatch_lines(
         [
             "E       UserWarning: user warning",
@@ -131,7 +133,7 @@ def test_ignore(testdir, pyfile_with_warnings, method):
 def test_unicode(testdir, pyfile_with_warnings):
     testdir.makepyfile(
         """
-        # -*- coding: utf8 -*-
+        # -*- coding: utf-8 -*-
         import warnings
         import pytest
 
@@ -166,7 +168,7 @@ def test_py2_unicode(testdir, pyfile_with_warnings):
         pytest.xfail("fails with unicode error on PyPy2 5.9 and Windows (#2905)")
     testdir.makepyfile(
         """
-        # -*- coding: utf8 -*-
+        # -*- coding: utf-8 -*-
         import warnings
         import pytest
 
@@ -300,7 +302,7 @@ def test_filterwarnings_mark_registration(testdir):
             pass
     """
     )
-    result = testdir.runpytest("--strict")
+    result = testdir.runpytest("--strict-markers")
     assert result.ret == 0
 
 
@@ -575,7 +577,7 @@ def test_infinite_loop_warning_against_unicode_usage_py2(testdir):
     """
     testdir.makepyfile(
         """
-        # -*- coding: utf8 -*-
+        # -*- coding: utf-8 -*-
         from __future__ import unicode_literals
         import warnings
         import pytest
@@ -628,7 +630,7 @@ def test_removed_in_pytest4_warning_as_error(testdir, change_default):
 class TestAssertionWarnings:
     @staticmethod
     def assert_result_warns(result, msg):
-        result.stdout.fnmatch_lines(["*PytestWarning: %s*" % msg])
+        result.stdout.fnmatch_lines(["*PytestAssertRewriteWarning: %s*" % msg])
 
     def test_tuple_warning(self, testdir):
         testdir.makepyfile(
